.. -*-restructuredtext-*-

.. image:: https://github.com/ubernostrum/django-contact-form/workflows/CI/badge.svg
   :alt: CI status image
   :target: https://github.com/ubernostrum/django-contact-form/actions?query=workflow%3ACI

This application provides extensible contact-form functionality for
`Django <https://www.djangoproject.com/>`_ sites.

Full documentation for all functionality is included and is also
`available online <http://django-contact-form.readthedocs.io/>`_.